@@ -388,7 +388,12 @@ def is_generic_type(type_):
     )
 
 
-def _try_import_forward_ref(thing, bound):  # pragma: no cover
+__EVAL_TYPE_TAKES_TYPE_PARAMS = (
+    "type_params" in inspect.signature(typing._eval_type).parameters  # type: ignore
+)
+
+
+def _try_import_forward_ref(thing, bound, *, type_params):  # pragma: no cover
     """
     Tries to import a real bound type from ``TypeVar`` bound to a ``ForwardRef``.
 
@@ -397,7 +402,10 @@ def _try_import_forward_ref(thing, bound):  # pragma: no cover
     because we can only cover each path in a separate python version.
     """
     try:
-        return typing._eval_type(bound, vars(sys.modules[thing.__module__]), None)
+        kw = {"globalns": vars(sys.modules[thing.__module__]), "localns": None}
+        if __EVAL_TYPE_TAKES_TYPE_PARAMS:
+            kw["type_params"] = type_params
+        return typing._eval_type(bound, **kw)
     except (KeyError, AttributeError, NameError):
         # We fallback to `ForwardRef` instance, you can register it as a type as well:
         # >>> from typing import ForwardRef
@@ -506,8 +514,9 @@ def from_typing_type(thing):
             for T in [*union_elems, elem_type]
         ):
             mapping.pop(bytes, None)
-            mapping.pop(collections.abc.ByteString, None)
-            mapping.pop(typing.ByteString, None)
+            if sys.version_info[:2] <= (3, 13):
+                mapping.pop(collections.abc.ByteString, None)
+                mapping.pop(typing.ByteString, None)
     elif (
         (not mapping)
         and isinstance(thing, typing.ForwardRef)
@@ -691,14 +700,16 @@ if sys.version_info[:2] >= (3, 9):
     # which includes this... but we don't actually ever want to build one.
     _global_type_lookup[os._Environ] = st.just(os.environ)
 
+if sys.version_info[:2] <= (3, 13):
+    # Note: while ByteString notionally also represents the bytearray and
+    # memoryview types, it is a subclass of Hashable and those types are not.
+    # We therefore only generate the bytes type. type-ignored due to deprecation.
+    _global_type_lookup[typing.ByteString] = st.binary()  # type: ignore
+    _global_type_lookup[collections.abc.ByteString] = st.binary()  # type: ignore
+
 
 _global_type_lookup.update(
     {
-        # Note: while ByteString notionally also represents the bytearray and
-        # memoryview types, it is a subclass of Hashable and those types are not.
-        # We therefore only generate the bytes type. type-ignored due to deprecation.
-        typing.ByteString: st.binary(),  # type: ignore
-        collections.abc.ByteString: st.binary(),  # type: ignore
         # TODO: SupportsAbs and SupportsRound should be covariant, ie have functions.
         typing.SupportsAbs: st.one_of(
             st.booleans(),
@@ -1030,7 +1041,9 @@ def resolve_TypeVar(thing):
     if getattr(thing, "__bound__", None) is not None:
         bound = thing.__bound__
         if isinstance(bound, typing.ForwardRef):
-            bound = _try_import_forward_ref(thing, bound)
+            # TODO: on Python 3.13 and later, we should work out what type_params
+            #       could be part of this type, and pass them in here.
+            bound = _try_import_forward_ref(thing, bound, type_params=())
         strat = unwrap_strategies(st.from_type(bound))
         if not isinstance(strat, OneOfStrategy):
             return strat
